package org.jboss.as7.demo.ejb;

import javax.annotation.PostConstruct;
import javax.ejb.ActivationConfigProperty;
import javax.ejb.MessageDriven;
import javax.inject.Inject;
import javax.jms.JMSException;
import javax.jms.Message;
import javax.jms.MessageListener;
import javax.jms.ObjectMessage;

import org.jboss.solder.logging.Logger;

/**
 * Message-Driven Bean implementation class for: MessageLogger
 *
 */
@MessageDriven(name = "jms/testQueue", activationConfig = {
    @ActivationConfigProperty(propertyName = "destinationType", propertyValue = "javax.jms.Queue"),
    @ActivationConfigProperty(propertyName = "destination", propertyValue = "java:/queue/test") })
public class MessageLogger implements MessageListener {

    @Inject
    private Logger logger;

    public MessageLogger() {
    }

    @PostConstruct
    void logConstructionMessage() {
        logger.info("Created");
    }

    /**
     * @see MessageListener#onMessage(Message)
     */
    @Override
    public void onMessage(Message message) {
        try {
            if ( message instanceof ObjectMessage ) {
                ObjectMessage objMessage = (ObjectMessage) message;
                logger.infof("Received message '%s'", objMessage.getObject().toString());
            } else
                logger.errorf("Received unknown message type '%s'", message.getClass().toString());
        } catch (JMSException e) {
            logger.error("Failed to retrieve object from ObjectMessage'", e);
        }

    }

}
