package org.jboss.as7.demo.ejb;

import javax.annotation.Resource;
import javax.ejb.EJBException;
import javax.ejb.LocalBean;
import javax.ejb.Stateless;
import javax.inject.Inject;
import javax.jms.Connection;
import javax.jms.ConnectionFactory;
import javax.jms.JMSException;
import javax.jms.Message;
import javax.jms.MessageProducer;
import javax.jms.Queue;
import javax.jms.Session;

import org.jboss.solder.logging.Logger;

/**
 * Session Bean implementation class Messenger
 */
@Stateless
@LocalBean
public class Messenger {

    @Inject
    private Logger logger;
    
    @Resource(mappedName = "java:/JmsXA")
    private ConnectionFactory connectionFactory;

    @Resource(mappedName = "java:/queue/test")
    private Queue testQueue;

    public Messenger() {
    }

    public void sendMessage(String message) {
        logger.infof("Queueing message '%s'", message);
        
        try {
            Connection connection = connectionFactory.createConnection();
            try {
                Session session = connection.createSession(true, 0);
                MessageProducer producer = session.createProducer(testQueue);
                Message jmsMessage = session.createObjectMessage(message);
                producer.send(jmsMessage);
            } finally {
                connection.close();
            }
        } catch (JMSException e) {
            throw new EJBException("Failed to send JMS message", e);
        }
        
    }

}
